@@ -30,8 +30,8 @@
 
 void init_postulates (void)
 {
-  A68 (top_postulate) = NO_POSTULATE;
-  A68 (top_postulate_list) = NO_POSTULATE;
+  A68G (top_postulate) = NO_POSTULATE;
+  A68G (top_postulate_list) = NO_POSTULATE;
 }
 
 //! @brief Make old postulates available for new use.
@@ -45,8 +45,8 @@ void free_postulate_list (POSTULATE_T * start, const POSTULATE_T * stop)
   for (; NEXT (last) != stop; FORWARD (last)) {
     ;
   }
-  NEXT (last) = A68 (top_postulate_list);
-  A68 (top_postulate_list) = start;
+  NEXT (last) = A68G (top_postulate_list);
+  A68G (top_postulate_list) = start;
 }
 
 //! @brief Add postulates to postulate-list.
@@ -54,12 +54,12 @@ void free_postulate_list (POSTULATE_T * start, const POSTULATE_T * stop)
 void make_postulate (POSTULATE_T ** p, MOID_T * a, MOID_T * b)
 {
   POSTULATE_T *new_one;
-  if (A68 (top_postulate_list) != NO_POSTULATE) {
-    new_one = A68 (top_postulate_list);
-    FORWARD (A68 (top_postulate_list));
+  if (A68G (top_postulate_list) != NO_POSTULATE) {
+    new_one = A68G (top_postulate_list);
+    FORWARD (A68G (top_postulate_list));
   } else {
     new_one = (POSTULATE_T *) get_temp_heap_space ((size_t) SIZE_ALIGNED (POSTULATE_T));
-    A68 (new_postulates)++;
+    A68G (new_postulates)++;
   }
   A (new_one) = a;
   B (new_one) = b;
