@@ -810,15 +810,20 @@ void genie_exec_sub_output (NODE_T * p)
       do {
         ret = (int) waitpid ((a68g_pid_t) pid, &status, 0);
       } while (ret == -1 && errno == EINTR);
-      if (ret != pid) {
-        status = -1;
-      }
-      if (!IS_NIL (dest)) {
-        *DEREF (A68G_REF, &dest) = c_to_a_string (p, get_transput_buffer (INPUT_BUFFER), get_transput_buffer_index (INPUT_BUFFER));
+      if (ret == pid) {
+        if (!IS_NIL (dest)) {
+          *DEREF (A68G_REF, &dest) = c_to_a_string (p, get_transput_buffer (INPUT_BUFFER), get_transput_buffer_index (INPUT_BUFFER));
+        }
+        if (WIFEXITED (status)) {
+          PUSH_VALUE (p, WEXITSTATUS (status), A68G_INT);
+        } else {
+          PUSH_VALUE (p, -1, A68G_INT);
+        }
+      } else {
+        PUSH_VALUE (p, -1, A68G_INT);
       }
       ASSERT (close (ptoc_fd[FD_WRITE]) == 0);
       ASSERT (close (ctop_fd[FD_READ]) == 0);
-      PUSH_VALUE (p, ret, A68G_INT);
     }
   #endif
 }
@@ -837,10 +842,13 @@ void genie_create_pipe (NODE_T * p)
 
 void genie_waitpid (NODE_T * p)
 {
-  errno = 0;
   A68G_INT k;
   POP_OBJECT (p, &k, A68G_INT);
   #if defined (BUILD_UNIX)
-    ASSERT (waitpid ((a68g_pid_t) VALUE (&k), NULL, 0) != -1);
+    errno = 0;
+    int ret;
+    do {
+      ret = (int) waitpid ((a68g_pid_t) VALUE (&k), NULL, 0);
+    } while (ret == -1 && errno == EINTR);
   #endif
 }
