@@ -94,7 +94,7 @@ MP_T *G_cfrac_lower_mp (NODE_T *q, MP_T * Gcfrac, MP_T *p, MP_T *x, int digs)
     SET_MP_ZERO (Gcfrac, digs);
     return Gcfrac;
   }
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *c = nil_mp (q, digs);
   MP_T *d = nil_mp (q, digs);
   MP_T *del = nil_mp (q, digs);
@@ -116,20 +116,20 @@ MP_T *G_cfrac_lower_mp (NODE_T *q, MP_T * Gcfrac, MP_T *p, MP_T *x, int digs)
   MP_T *n = lit_mp (q, 2, 0, digs);
   MP_T *k = nil_mp (q, digs);
   MP_T *two = lit_mp (q, 2, 0, digs);
-  BOOL_T odd = A68_FALSE, cont = A68_TRUE;
+  BOOL_T odd = A68G_FALSE, cont = A68G_TRUE;
   while (cont) {
-    A68_BOOL ge, lt;
+    A68G_BOOL ge, lt;
 //  k = n / 2;
     (void) over_mp (q, k, n, two, digs);    
 //  an = (n & 1 ? k : -(p - 1 + k)) * x;
     if (odd) {
       (void) move_mp (an, k, digs);
-      odd = A68_FALSE;
+      odd = A68G_FALSE;
     } else {
       (void) minus_one_mp (q, trm, p, digs);
       (void) add_mp (q, trm, trm, k, digs);
       (void) minus_mp (q, an, trm, digs);
-      odd = A68_TRUE;
+      odd = A68G_TRUE;
     }
     (void) mul_mp (q, an, an, x, digs);
 //  bn++;
@@ -164,7 +164,7 @@ MP_T *G_cfrac_lower_mp (NODE_T *q, MP_T * Gcfrac, MP_T *p, MP_T *x, int digs)
     cont = VALUE (&ge) && VALUE (&lt);
   }
   (void) move_mp (Gcfrac, f, digs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return Gcfrac;
 }
 
@@ -174,7 +174,7 @@ MP_T *G_cfrac_lower_mp (NODE_T *q, MP_T * Gcfrac, MP_T *p, MP_T *x, int digs)
 
 MP_T *G_cfrac_upper_mp (NODE_T *q, MP_T * Gcfrac, MP_T *p, MP_T *x, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   if (PLUS_INF_MP (x)) {
     SET_MP_ZERO (Gcfrac, digs);
     return Gcfrac;
@@ -229,9 +229,9 @@ MP_T *G_cfrac_upper_mp (NODE_T *q, MP_T * Gcfrac, MP_T *p, MP_T *x, int digs)
   }
 //  i = n - 1;
   minus_one_mp (q, i, n, digs); 
-  BOOL_T cont = A68_TRUE;  
+  BOOL_T cont = A68G_TRUE;  
   while (cont) {
-    A68_BOOL ge, lt;
+    A68G_BOOL ge, lt;
 //  an = -i * (i - p);
     (void) sub_mp (q, trm, p, i, digs);
     (void) mul_mp (q, an, i, trm, digs);
@@ -268,7 +268,7 @@ MP_T *G_cfrac_upper_mp (NODE_T *q, MP_T * Gcfrac, MP_T *p, MP_T *x, int digs)
     (void) lt_mp (q, &lt, n, itmax, digs);
     cont = VALUE (&ge) && VALUE (&lt);
   }
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
 // *Gcfrac = t ? f : 1 / f;
   if (t) {
     (void) move_mp (Gcfrac, f, digs);
@@ -285,7 +285,7 @@ MP_T *G_cfrac_upper_mp (NODE_T *q, MP_T * Gcfrac, MP_T *p, MP_T *x, int digs)
 
 MP_T *G_ibp_mp (NODE_T *q, MP_T * Gibp, MP_T *p, MP_T *x, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *trm = nil_mp (q, digs), *trn = nil_mp (q, digs);
   MP_T *eps = EPS (q, digs);
 // t = fabs_double (x);
@@ -312,7 +312,7 @@ MP_T *G_ibp_mp (NODE_T *q, MP_T * Gibp, MP_T *p, MP_T *x, int digs)
   (void) mul_mp (q, s, c, trm, digs);
 // l = 0;
   MP_T *l = nil_mp (q, digs);
-  BOOL_T cont = A68_TRUE, stop = A68_TRUE;
+  BOOL_T cont = A68G_TRUE, stop = A68G_TRUE;
   MP_T *del = nil_mp (q, digs);
   while (cont) {
 //  c *= d * (d - 1) * tt;
@@ -333,7 +333,7 @@ MP_T *G_ibp_mp (NODE_T *q, MP_T * Gibp, MP_T *p, MP_T *x, int digs)
     (void) abs_mp (q, trm, del, digs);
     (void) abs_mp (q, trn, s, digs);
     (void) mul_mp (q, trn, trn, eps, digs);
-    A68_BOOL lt;
+    A68G_BOOL lt;
     (void) lt_mp (q, &lt, trm, trn, digs);
     stop = VALUE (&lt);
 //while ((l < floor_double ((p - 2) / 2)) && !stop);
@@ -362,19 +362,19 @@ MP_T *G_ibp_mp (NODE_T *q, MP_T * Gibp, MP_T *p, MP_T *x, int digs)
   }
   (void) add_mp (q, Gibp, Gibp, s, digs);
   (void) div_mp (q, Gibp, Gibp, t, digs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return Gibp;
 }
 
 MP_T *plim_mp (NODE_T *p, MP_T *z, MP_T *x, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   if (MP_DIGIT (x, 1) > 0) {
     (void) move_mp (z, x, digs);
   } else {
     MP_T *five = lit_mp (p, 5, 0, digs);
     MP_T *nine = lit_mp (p, -9, 0, digs);
-    A68_BOOL ge;
+    A68G_BOOL ge;
     (void) ge_mp (p, &ge, x, nine, digs);
     if (VALUE (&ge)) {
       SET_MP_ZERO (z, digs);
@@ -385,7 +385,7 @@ MP_T *plim_mp (NODE_T *p, MP_T *z, MP_T *x, int digs)
       (void) sub_mp (p, z, z, five, digs);
     }
   }
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return z;
 }
 
@@ -398,9 +398,9 @@ MP_T *plim_mp (NODE_T *p, MP_T *z, MP_T *x, int digs)
 
 void G_func_mp (NODE_T *q, MP_T * G, MP_T *p, MP_T *x, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *pl = nil_mp (q, digs);
-  A68_BOOL ge;
+  A68G_BOOL ge;
   (void) plim_mp (q, pl, x, digs);
   (void) ge_mp (q, &ge, p, pl, digs);
   if (VALUE (&ge)) {
@@ -410,7 +410,7 @@ void G_func_mp (NODE_T *q, MP_T * G, MP_T *p, MP_T *x, int digs)
   } else {
     G_cfrac_upper_mp (q, G, p, x, digs);
   }
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
 }
 
 //! @brief compute I_{x,y}^{mu,p} using a Romberg approximation.
@@ -433,8 +433,8 @@ void mp_romberg_iterations
   INT_T adr0_prev = ((n - 1) * n) / 2;
   INT_T adr0 = (n * (n + 1)) / 2;
   MP_T *j = lit_mp (q, 1, 0, digs);
-  A68_BOOL le;
-  VALUE (&le) = A68_TRUE;
+  A68G_BOOL le;
+  VALUE (&le) = A68G_TRUE;
   while (VALUE (&le)) {
 //  xx = x + ((y - x) * (2 * j - 1)) / (2 * pow2);
     (void) add_mp (q, trm, j, j, digs);
@@ -477,7 +477,7 @@ void mp_romberg_iterations
 
 void mp_romberg_estimate (NODE_T *q, MP_T * rho, MP_T * sigma, MP_T *x, MP_T *y, MP_T *mu, MP_T *p, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *R = (MP_T *) get_heap_space (ROMBERG_N * SIZE_MP (digs));
 // Initialization (n=1)
   MP_T *trm = nil_mp (q, digs), *trn = nil_mp (q, digs);
@@ -511,13 +511,13 @@ void mp_romberg_estimate (NODE_T *q, MP_T * rho, MP_T * sigma, MP_T *x, MP_T *y,
   (void) half_mp (q, h, h, digs);
 //  REAL_T pow2 = 1;              // n=1; pow2 = 2^(n-1)
   MP_T *pow2 = lit_mp (q, 1, 0, digs);
-  BOOL_T cont = A68_TRUE;
+  BOOL_T cont = A68G_TRUE;
   while (cont) {
 // while (n <= NITERMAX_ROMBERG && relerr > relneeded);
 //  mp_romberg_iterations (R, *sigma, n, x, y, mu, p, h, pow2);
-    ADDR_T pop_sp_2 = A68_SP;
+    ADDR_T pop_sp_2 = A68G_SP;
     mp_romberg_iterations (q, R, sigma, n, x, y, mu, p, h, pow2, digs);
-    A68_SP = pop_sp_2;
+    A68G_SP = pop_sp_2;
 //  h /= 2;
     (void) half_mp (q, h, h, digs);
 //  pow2 *= 2;
@@ -530,7 +530,7 @@ void mp_romberg_estimate (NODE_T *q, MP_T * rho, MP_T * sigma, MP_T *x, MP_T *y,
     (void) abs_mp (q, relerr, trm, digs);
 //  n++;
     n++; 
-    A68_BOOL gt;
+    A68G_BOOL gt;
     (void) gt_mp (q, &gt, relerr, relneeded, digs);
     cont = (n <= NITERMAX_ROMBERG) && VALUE (&gt);
   }
@@ -538,7 +538,7 @@ void mp_romberg_estimate (NODE_T *q, MP_T * rho, MP_T * sigma, MP_T *x, MP_T *y,
 // rho = R[adr0 + (n - 1)];
   (void) move_mp (rho, &R[IX (adr0 + n - 1, digs)], digs);
   a68g_free (R);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
 }
 
 //! @brief compute generalized incomplete gamma function I_{x,y}^{mu,p}
@@ -553,19 +553,19 @@ void mp_romberg_estimate (NODE_T *q, MP_T * rho, MP_T * sigma, MP_T *x, MP_T *y,
 
 void Dgamic_mp (NODE_T *q, MP_T * rho, MP_T * sigma, MP_T *x, MP_T *y, MP_T *mu, MP_T *p, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
 // Particular cases
   if (PLUS_INF_MP (x) && PLUS_INF_MP (y)) {
     SET_MP_ZERO (rho, digs);
     SET_MP_ZERO (sigma, digs);
     MP_STATUS (sigma) = (UNSIGNED_T) MP_STATUS (sigma) | MINUS_INF_MASK;
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     return;
   } else if (same_mp (q, x, y, digs)) {
     SET_MP_ZERO (rho, digs);
     SET_MP_ZERO (sigma, digs);
     MP_STATUS (sigma) = (UNSIGNED_T) MP_STATUS (sigma) | MINUS_INF_MASK;
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     return;
   }
   if (IS_ZERO_MP (x) && PLUS_INF_MP (y)) {
@@ -586,7 +586,7 @@ void Dgamic_mp (NODE_T *q, MP_T * rho, MP_T * sigma, MP_T *x, MP_T *y, MP_T *mu,
   MP_T *mux = nil_mp (q, digs);
   MP_T *muy = nil_mp (q, digs);
 // Initialization
-// nx = (a68g_isinf_real (x) ? a68g_neginf_double_real () : -mu * x + p * ln (x));
+// nx = (a68g_isinf_real (x) ? a68g_mininf_real () : -mu * x + p * ln (x));
   if (PLUS_INF_MP (x)) {
     SET_MP_ZERO (mx, digs);
     MP_STATUS (nx) = (UNSIGNED_T) MP_STATUS (nx) | MINUS_INF_MASK;
@@ -597,7 +597,7 @@ void Dgamic_mp (NODE_T *q, MP_T * rho, MP_T * sigma, MP_T *x, MP_T *y, MP_T *mu,
     (void) mul_mp (q, nx, p, nx, digs);
     (void) sub_mp (q, nx, nx, mux, digs);
   }
-// ny = (a68g_isinf_real (y) ? a68g_neginf_double_real () : -mu * y + p * ln (y));
+// ny = (a68g_isinf_real (y) ? a68g_mininf_real () : -mu * y + p * ln (y));
   if (PLUS_INF_MP (y)) {
     SET_MP_ZERO (my, digs);
     MP_STATUS (ny) = (UNSIGNED_T) MP_STATUS (ny) | MINUS_INF_MASK;
@@ -626,9 +626,9 @@ void Dgamic_mp (NODE_T *q, MP_T * rho, MP_T * sigma, MP_T *x, MP_T *y, MP_T *mu,
     goto compute;
   }
   MP_T *pl = nil_mp (q, digs);
-  A68_BOOL lt;
+  A68G_BOOL lt;
   if (PLUS_INF_MP (x)) {
-    VALUE (&lt) = A68_TRUE;
+    VALUE (&lt) = A68G_TRUE;
   } else {
     (void) mul_mp (q, mux, mu, x, digs);
     (void) plim_mp (q, pl, mux, digs);
@@ -642,7 +642,7 @@ void Dgamic_mp (NODE_T *q, MP_T * rho, MP_T * sigma, MP_T *x, MP_T *y, MP_T *mu,
     goto compute;
   }
   if (PLUS_INF_MP (y)) {
-    VALUE (&lt) = A68_TRUE;
+    VALUE (&lt) = A68G_TRUE;
   } else {
     (void) mul_mp (q, muy, mu, y, digs);
     (void) plim_mp (q, pl, muy, digs);
@@ -659,9 +659,9 @@ void Dgamic_mp (NODE_T *q, MP_T * rho, MP_T * sigma, MP_T *x, MP_T *y, MP_T *mu,
     (void) mul_mp (q, lnmu, p, lnmu, digs);
     (void) sub_mp (q, nA, lgam, lnmu, digs);
 //  nB = fmax (nx, ny);
-    A68_BOOL ge;
+    A68G_BOOL ge;
     if (MINUS_INF_MP (ny)) {
-      VALUE (&ge) = A68_TRUE;
+      VALUE (&ge) = A68G_TRUE;
     } else {
       (void) ge_mp (q, &ge, nx, ny, digs);
     }
@@ -702,12 +702,12 @@ void Dgamic_mp (NODE_T *q, MP_T * rho, MP_T * sigma, MP_T *x, MP_T *y, MP_T *mu,
   if (!PLUS_INF_MP (y) && VALUE (&lt)) {
     mp_romberg_estimate (q, rho, sigma, x, y, mu, p, digs);
   }
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
 }
 
 void Dgamic_wrap_mp (NODE_T *q, MP_T * s, MP_T * rho, MP_T * sigma, MP_T *x, MP_T *y, MP_T *mu, MP_T *p, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int gdigs = GAM_DIGITS (MAX_PRECISION);
   errno = 0;
   if (digs <= gdigs) {
@@ -727,7 +727,7 @@ void Dgamic_wrap_mp (NODE_T *q, MP_T * s, MP_T * rho, MP_T * sigma, MP_T *x, MP_
       (void) shorten_mp (q, s, digs, rho_g, gdigs);
     }
   } else {
-    diagnostic (A68_MATH_WARNING, q, WARNING_MATH_PRECISION, MOID (q), CALL, NULL);
+    diagnostic (A68G_MATH_WARNING, q, WARNING_MATH_PRECISION, MOID (q), CALL, NULL);
     MP_T *rho_g = cut_mp (q, rho, digs, gdigs);
     MP_T *sigma_g = cut_mp (q, sigma, digs, gdigs);
     MP_T *x_g = cut_mp (q, x, digs, gdigs);
@@ -746,7 +746,7 @@ void Dgamic_wrap_mp (NODE_T *q, MP_T * s, MP_T * rho, MP_T * sigma, MP_T *x, MP_
     }
   }
   PRELUDE_ERROR (errno != 0, q, ERROR_MATH, MOID (q));
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
 }
 
 //! @brief PROC long long gamma inc f = (LONG LONG REAL p, x) LONG LONG REAL
@@ -754,7 +754,7 @@ void Dgamic_wrap_mp (NODE_T *q, MP_T * s, MP_T * rho, MP_T * sigma, MP_T *x, MP_
 void genie_gamma_inc_f_mp (NODE_T *p)
 {
   int digs = DIGITS (MOID (p)), size = SIZE (MOID (p));
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *x = (MP_T *) STACK_OFFSET (-size);
   MP_T *s = (MP_T *) STACK_OFFSET (-2 * size);
   MP_T *mu = lit_mp (p, 1, 0, digs);
@@ -763,8 +763,8 @@ void genie_gamma_inc_f_mp (NODE_T *p)
   MP_T *sigma = nil_mp (p, digs);
   MP_STATUS (y) = (UNSIGNED_T) MP_STATUS (y) | PLUS_INF_MASK;
   Dgamic_wrap_mp (p, s, rho, sigma, x, y, mu, s, digs);
-  A68_SP = pop_sp;
-  A68_SP -= size;
+  A68G_SP = pop_sp;
+  A68G_SP -= size;
 }
 
 //! @brief PROC long long gamma inc g = (LONG LONG REAL p, x, y, mu) LONG LONG REAL
@@ -772,7 +772,7 @@ void genie_gamma_inc_f_mp (NODE_T *p)
 void genie_gamma_inc_g_mp (NODE_T *p)
 {
   int digs = DIGITS (MOID (p)), size = SIZE (MOID (p));
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *mu = (MP_T *) STACK_OFFSET (-size);
   MP_T *y = (MP_T *) STACK_OFFSET (-2 * size);
   MP_T *x = (MP_T *) STACK_OFFSET (-3 * size);
@@ -780,8 +780,8 @@ void genie_gamma_inc_g_mp (NODE_T *p)
   MP_T *rho = nil_mp (p, digs);
   MP_T *sigma = nil_mp (p, digs);
   Dgamic_wrap_mp (p, s, rho, sigma, x, y, mu, s, digs);
-  A68_SP = pop_sp;
-  A68_SP -= 3 * size;
+  A68G_SP = pop_sp;
+  A68G_SP -= 3 * size;
 }
 
 //! @brief PROC long long gamma inc gf = (LONG LONG REAL p, x, y, mu) LONG LONG REAL
@@ -791,7 +791,7 @@ void genie_gamma_inc_gf_mp (NODE_T *p)
 // if x <= p: G(p,x) = exp (x-p*ln (|x|)) * integral over [0,|x|] of s^{p-1} * exp (-sign (x)*s) ds
 // otherwise: G(p,x) = exp (x-p*ln (x)) * integral over [x,inf] of s^{p-1} * exp (-s) ds
   int digs = DIGITS (MOID (p)), size = SIZE (MOID (p));
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *x = (MP_T *) STACK_OFFSET (-size);
   MP_T *s = (MP_T *) STACK_OFFSET (-2 * size);
   int gdigs = GAM_DIGITS (MAX_PRECISION);
@@ -805,7 +805,7 @@ void genie_gamma_inc_gf_mp (NODE_T *p)
     PRELUDE_ERROR (errno != 0, p, ERROR_MATH, MOID (p));
     (void) shorten_mp (p, s, digs, G, gdigs);
   } else {
-    diagnostic (A68_MATH_WARNING, p, WARNING_MATH_PRECISION, MOID (p), CALL, NULL);
+    diagnostic (A68G_MATH_WARNING, p, WARNING_MATH_PRECISION, MOID (p), CALL, NULL);
     MP_T *x_g = cut_mp (p, x, digs, gdigs);
     MP_T *s_g = cut_mp (p, s, digs, gdigs);
     MP_T *G = nil_mp (p, gdigs);
@@ -815,14 +815,14 @@ void genie_gamma_inc_gf_mp (NODE_T *p)
     (void) shorten_mp (p, tmp, MAX_PRECISION, G, gdigs);
     (void) lengthen_mp (p, s, digs, tmp, MAX_PRECISION);
   }
-  A68_SP = pop_sp - size;
+  A68G_SP = pop_sp - size;
 }
 
 //! @brief PROC long long gamma inc = (LONG LONG REAL p, x) LONG LONG REAL
 
 void genie_gamma_inc_h_mp (NODE_T *p)
 {
-// #if defined (HAVE_GNU_MPFR) && (A68_LEVEL >= 3)
+// #if defined (HAVE_GNU_MPFR) && (A68G_LEVEL >= 3)
 //   genie_gamma_inc_mpfr (p);
 // #else
 //   genie_gamma_inc_f_mp (p);
