@@ -28,7 +28,11 @@
 
 // This is part of the bottom-up parser.
 // Here is a set of routines that gather definitions from phrases.
-// This way we can apply tags before defining them.
+//
+// This way we can apply tags before defining them, but more importantly,
+// with this information the Algol 68 two level Van Wijngaarden grammar
+// reduces to LALR.
+//
 // These routines do not look very elegant as they have to scan through all
 // kind of symbols to find a pattern that they recognise.
 
@@ -243,10 +247,10 @@ void extract_priorities (NODE_T * p)
           FORWARD (q);
         } else if (whether (q, BOLD_TAG, INT_DENOTATION, STOP) || whether (q, OPERATOR, INT_DENOTATION, STOP) || whether (q, EQUALS_SYMBOL, INT_DENOTATION, STOP)) {
 // The scanner cannot separate operator and "=" sign so we do this here.
-          int len = (int) strlen (NSYMBOL (q));
+          size_t len = strlen (NSYMBOL (q));
           if (len > 1 && NSYMBOL (q)[len - 1] == '=') {
             NODE_T *y = q;
-            char *sym = (char *) get_temp_heap_space ((size_t) (len + 1));
+            char *sym = (char *) get_temp_heap_space (len + 1);
             a68g_bufcpy (sym, NSYMBOL (q), len + 1);
             sym[len - 1] = NULL_CHAR;
             NSYMBOL (q) = TEXT (add_token (&A68G (top_token), sym));
@@ -319,9 +323,9 @@ void extract_operators (NODE_T * p)
             q = skip_unit (q);
           } else if (q != NO_NODE && (is_one_of (q, OPERATOR, BOLD_TAG, EQUALS_SYMBOL, STOP))) {
 // The scanner cannot separate operator and "=" sign so we do this here.
-            int len = (int) strlen (NSYMBOL (q));
+            size_t len = strlen (NSYMBOL (q));
             if (len > 1 && NSYMBOL (q)[len - 1] == '=') {
-              char *sym = (char *) get_temp_heap_space ((size_t) (len + 1));
+              char *sym = (char *) get_temp_heap_space (len + 1);
               a68g_bufcpy (sym, NSYMBOL (q), len + 1);
               sym[len - 1] = NULL_CHAR;
               NSYMBOL (q) = TEXT (add_token (&A68G (top_token), sym));
