@@ -23,8 +23,8 @@
 //!
 //! Static scope checker.
 
-// A static scope checker inspects the source. Note that Algol 68 also 
-// needs dynamic scope checking. This phase concludes the parser.
+// A static scope checker inspects the source. 
+// Note that Algol 68 also needs dynamic scope checking.
 
 #include "a68g.h"
 #include "a68g-parser.h"
@@ -75,7 +75,7 @@ TUPLE_T scope_make_tuple (int e, int t)
 void scope_add (SCOPE_T ** sl, NODE_T * p, TUPLE_T tup)
 {
   if (sl != NO_REF) {
-    SCOPE_T *ns = (SCOPE_T *) get_temp_heap_space ((unt) SIZE_ALIGNED (SCOPE_T));
+    SCOPE_T *ns = (SCOPE_T *) get_temp_heap_space (SIZE_ALIGNED (SCOPE_T));
     WHERE (ns) = p;
     TUPLE (ns) = tup;
     NEXT (ns) = *sl;
@@ -92,7 +92,7 @@ BOOL_T scope_check (SCOPE_T * top, int mask, int dest)
   if (mask & TRANSIENT) {
     for (SCOPE_T *s = top; s != NO_SCOPE; FORWARD (s)) {
       if (TRANSIENT (&TUPLE (s)) & TRANSIENT) {
-        diagnostic (A68_ERROR, WHERE (s), ERROR_TRANSIENT_NAME);
+        diagnostic (A68G_ERROR, WHERE (s), ERROR_TRANSIENT_NAME);
         STATUS_SET (WHERE (s), SCOPE_ERROR_MASK);
         errors++;
       }
@@ -104,7 +104,7 @@ BOOL_T scope_check (SCOPE_T * top, int mask, int dest)
       MOID_T *ws = MOID (WHERE (s));
       if (ws != NO_MOID) {
         if (IS_REF (ws) || IS (ws, PROC_SYMBOL) || IS (ws, FORMAT_SYMBOL) || IS (ws, UNION_SYMBOL)) {
-          diagnostic (A68_WARNING, WHERE (s), WARNING_SCOPE_STATIC, MOID (WHERE (s)), ATTRIBUTE (WHERE (s)));
+          diagnostic (A68G_WARNING, WHERE (s), WARNING_SCOPE_STATIC, MOID (WHERE (s)), ATTRIBUTE (WHERE (s)));
         }
       }
       STATUS_SET (WHERE (s), SCOPE_ERROR_MASK);
@@ -118,7 +118,7 @@ BOOL_T scope_check (SCOPE_T * top, int mask, int dest)
 
 BOOL_T scope_check_multiple (SCOPE_T * top, int mask, SCOPE_T * dest)
 {
-  BOOL_T no_err = A68_TRUE;
+  BOOL_T no_err = A68G_TRUE;
   for (; dest != NO_SCOPE; FORWARD (dest)) {
     no_err &= scope_check (top, mask, LEVEL (&TUPLE (dest)));
   }
@@ -131,7 +131,7 @@ void check_identifier_usage (TAG_T * t, NODE_T * p)
 {
   for (; p != NO_NODE; FORWARD (p)) {
     if (IS (p, IDENTIFIER) && TAX (p) == t && ATTRIBUTE (MOID (t)) != PROC_SYMBOL) {
-      diagnostic (A68_WARNING, p, WARNING_UNINITIALISED);
+      diagnostic (A68G_WARNING, p, WARNING_UNINITIALISED);
     }
     check_identifier_usage (t, SUB (p));
   }
@@ -154,7 +154,7 @@ TUPLE_T scope_find_youngest_outside (SCOPE_T * s, int treshold)
 
 TUPLE_T scope_find_youngest (SCOPE_T * s)
 {
-  return scope_find_youngest_outside (s, INT_MAX);
+  return scope_find_youngest_outside (s, A68G_MAX_LEX_LEVEL);
 }
 
 // Routines for determining scope of ROUTINE TEXT or FORMAT TEXT.
@@ -171,7 +171,7 @@ void get_declarer_elements (NODE_T * p, SCOPE_T ** r, BOOL_T no_ref)
         scope_add (r, p, scope_make_tuple (TAG_LEX_LEVEL (TAX (p)), NOT_TRANSIENT));
       }
     } else if (IS_REF (p)) {
-      get_declarer_elements (NEXT (p), r, A68_FALSE);
+      get_declarer_elements (NEXT (p), r, A68G_FALSE);
     } else if (is_one_of (p, PROC_SYMBOL, UNION_SYMBOL, STOP)) {
       ;
     } else {
@@ -206,7 +206,7 @@ void gather_scopes_for_youngest (NODE_T * p, SCOPE_T ** s)
         scope_add (s, p, scope_make_tuple (TAG_LEX_LEVEL (TAX (p)), NOT_TRANSIENT));
       }
     } else if (IS (p, DECLARER)) {
-      get_declarer_elements (p, s, A68_TRUE);
+      get_declarer_elements (p, s, A68G_TRUE);
     } else {
       gather_scopes_for_youngest (SUB (p), s);
     }
@@ -238,13 +238,13 @@ void bind_scope_to_tag (NODE_T * p)
     if (IS (p, DEFINING_IDENTIFIER) && MOID (p) == M_FORMAT) {
       if (IS (NEXT_NEXT (p), FORMAT_TEXT)) {
         SCOPE (TAX (p)) = YOUNGEST_ENVIRON (TAX (NEXT_NEXT (p)));
-        SCOPE_ASSIGNED (TAX (p)) = A68_TRUE;
+        SCOPE_ASSIGNED (TAX (p)) = A68G_TRUE;
       }
       return;
     } else if (IS (p, DEFINING_IDENTIFIER)) {
       if (IS (NEXT_NEXT (p), ROUTINE_TEXT)) {
         SCOPE (TAX (p)) = YOUNGEST_ENVIRON (TAX (NEXT_NEXT (p)));
-        SCOPE_ASSIGNED (TAX (p)) = A68_TRUE;
+        SCOPE_ASSIGNED (TAX (p)) = A68G_TRUE;
       }
       return;
     } else {
@@ -319,7 +319,7 @@ void scope_identity_declaration (NODE_T * p)
       z = LEVEL (&tup);
       if (z < LEX_LEVEL (p)) {
         SCOPE (TAX (p)) = z;
-        SCOPE_ASSIGNED (TAX (p)) = A68_TRUE;
+        SCOPE_ASSIGNED (TAX (p)) = A68G_TRUE;
       }
       STATUS_SET (unit, INTERRUPTIBLE_MASK);
       return;
@@ -420,14 +420,14 @@ BOOL_T is_coercion (NODE_T * p)
     case WIDENING:
     case VOIDING:
     case PROCEDURING: {
-        return A68_TRUE;
+        return A68G_TRUE;
       }
     default: {
-        return A68_FALSE;
+        return A68G_FALSE;
       }
     }
   } else {
-    return A68_FALSE;
+    return A68G_FALSE;
   }
 }
 
@@ -557,9 +557,9 @@ void scope_statement (NODE_T * p, SCOPE_T ** s)
           scope_add (s, p, scope_make_tuple (TAG_LEX_LEVEL (TAX (p)), NOT_TRANSIENT));
         }
       }
-    } else if (ATTRIBUTE (MOID (p)) == PROC_SYMBOL && SCOPE_ASSIGNED (TAX (p)) == A68_TRUE) {
+    } else if (ATTRIBUTE (MOID (p)) == PROC_SYMBOL && SCOPE_ASSIGNED (TAX (p)) == A68G_TRUE) {
       scope_add (s, p, scope_make_tuple (SCOPE (TAX (p)), NOT_TRANSIENT));
-    } else if (MOID (p) == M_FORMAT && SCOPE_ASSIGNED (TAX (p)) == A68_TRUE) {
+    } else if (MOID (p) == M_FORMAT && SCOPE_ASSIGNED (TAX (p)) == A68G_TRUE) {
       scope_add (s, p, scope_make_tuple (SCOPE (TAX (p)), NOT_TRANSIENT));
     }
   } else if (IS (p, ENCLOSED_CLAUSE)) {
@@ -704,7 +704,7 @@ void scope_serial_clause (NODE_T * p, SCOPE_T ** s, BOOL_T terminator)
 {
   if (p != NO_NODE) {
     if (IS (p, INITIALISER_SERIES)) {
-      scope_serial_clause (SUB (p), s, A68_FALSE);
+      scope_serial_clause (SUB (p), s, A68G_FALSE);
       scope_serial_clause (NEXT (p), s, terminator);
     } else if (IS (p, DECLARATION_LIST)) {
       scope_declaration_list (SUB (p));
@@ -714,12 +714,12 @@ void scope_serial_clause (NODE_T * p, SCOPE_T ** s, BOOL_T terminator)
       if (NEXT (p) != NO_NODE) {
         int j = ATTRIBUTE (NEXT (p));
         if (j == EXIT_SYMBOL || j == END_SYMBOL || j == CLOSE_SYMBOL) {
-          scope_serial_clause (SUB (p), s, A68_TRUE);
+          scope_serial_clause (SUB (p), s, A68G_TRUE);
         } else {
-          scope_serial_clause (SUB (p), s, A68_FALSE);
+          scope_serial_clause (SUB (p), s, A68G_FALSE);
         }
       } else {
-        scope_serial_clause (SUB (p), s, A68_TRUE);
+        scope_serial_clause (SUB (p), s, A68G_TRUE);
       }
       scope_serial_clause (NEXT (p), s, terminator);
     } else if (IS (p, LABELED_UNIT)) {
@@ -741,7 +741,7 @@ void scope_closed_clause (NODE_T * p, SCOPE_T ** s)
 {
   if (p != NO_NODE) {
     if (IS (p, SERIAL_CLAUSE)) {
-      scope_serial_clause (p, s, A68_TRUE);
+      scope_serial_clause (p, s, A68G_TRUE);
     } else if (is_one_of (p, OPEN_SYMBOL, BEGIN_SYMBOL, STOP)) {
       scope_closed_clause (NEXT (p), s);
     }
@@ -763,12 +763,12 @@ void scope_collateral_clause (NODE_T * p, SCOPE_T ** s)
 
 void scope_conditional_clause (NODE_T * p, SCOPE_T ** s)
 {
-  scope_serial_clause (NEXT_SUB (p), NO_REF, A68_TRUE);
+  scope_serial_clause (NEXT_SUB (p), NO_REF, A68G_TRUE);
   FORWARD (p);
-  scope_serial_clause (NEXT_SUB (p), s, A68_TRUE);
+  scope_serial_clause (NEXT_SUB (p), s, A68G_TRUE);
   if ((FORWARD (p)) != NO_NODE) {
     if (is_one_of (p, ELSE_PART, CHOICE, STOP)) {
-      scope_serial_clause (NEXT_SUB (p), s, A68_TRUE);
+      scope_serial_clause (NEXT_SUB (p), s, A68G_TRUE);
     } else if (is_one_of (p, ELIF_PART, BRIEF_ELIF_PART, STOP)) {
       scope_conditional_clause (SUB (p), s);
     }
@@ -780,13 +780,13 @@ void scope_conditional_clause (NODE_T * p, SCOPE_T ** s)
 void scope_case_clause (NODE_T * p, SCOPE_T ** s)
 {
   SCOPE_T *n = NO_SCOPE;
-  scope_serial_clause (NEXT_SUB (p), &n, A68_TRUE);
+  scope_serial_clause (NEXT_SUB (p), &n, A68G_TRUE);
   (void) scope_check (n, NOT_TRANSIENT, LEX_LEVEL (p));
   FORWARD (p);
   scope_statement_list (NEXT_SUB (p), s);
   if ((FORWARD (p)) != NO_NODE) {
     if (is_one_of (p, OUT_PART, CHOICE, STOP)) {
-      scope_serial_clause (NEXT_SUB (p), s, A68_TRUE);
+      scope_serial_clause (NEXT_SUB (p), s, A68G_TRUE);
     } else if (is_one_of (p, CASE_OUSE_PART, BRIEF_OUSE_PART, STOP)) {
       scope_case_clause (SUB (p), s);
     } else if (is_one_of (p, CONFORMITY_OUSE_PART, BRIEF_CONFORMITY_OUSE_PART, STOP)) {
@@ -806,18 +806,18 @@ void scope_loop_clause (NODE_T * p)
       scope_statement (NEXT_SUB (p), NO_REF);
       scope_loop_clause (NEXT (p));
     } else if (IS (p, WHILE_PART)) {
-      scope_serial_clause (NEXT_SUB (p), NO_REF, A68_TRUE);
+      scope_serial_clause (NEXT_SUB (p), NO_REF, A68G_TRUE);
       scope_loop_clause (NEXT (p));
     } else if (is_one_of (p, DO_PART, ALT_DO_PART, STOP)) {
       NODE_T *do_p = NEXT_SUB (p), *un_p;
       if (IS (do_p, SERIAL_CLAUSE)) {
-        scope_serial_clause (do_p, NO_REF, A68_TRUE);
+        scope_serial_clause (do_p, NO_REF, A68G_TRUE);
         un_p = NEXT (do_p);
       } else {
         un_p = do_p;
       }
       if (un_p != NO_NODE && IS (un_p, UNTIL_PART)) {
-        scope_serial_clause (NEXT_SUB (un_p), NO_REF, A68_TRUE);
+        scope_serial_clause (NEXT_SUB (un_p), NO_REF, A68G_TRUE);
       }
     }
   }
@@ -853,7 +853,7 @@ BOOL_T empty_table (TABLE_T * t)
   } else if (PRIO (IDENTIFIERS (t)) == SPECIFIER_IDENTIFIER && NEXT (IDENTIFIERS (t)) == NO_TAG) {
     return (BOOL_T) (OPERATORS (t) == NO_TAG && INDICANTS (t) == NO_TAG);
   } else {
-    return A68_FALSE;
+    return A68G_FALSE;
   }
 }
 
