@@ -28,19 +28,16 @@
 #include "a68g-optimiser.h"
 #include "a68g-options.h"
 
-#if defined (BUILD_A68G_COMPILER)
-
 //! @brief Build shell script from program.
 
+#if defined (BUILD_A68G_COMPILER)
+
 void build_script (void)
 {
-#if !defined (BUILD_A68G_COMPILER)
-  return;
-#endif
   BUFFER cmd;
   BUFCLR (cmd);
   announce_phase ("script builder");
-  ABEND (OPTION_OPT_LEVEL (&A68G_JOB) == 0, ERROR_ACTION, __func__);
+  ABEND (OPTION_OPT_LEVEL (&A68G_JOB) == 0, ERROR_ACTION, NO_TEXT);
 // Flatten the source file.
   ASSERT (a68g_bufprt (cmd, SNPRINTF_SIZE, "%s.%s", HIDDEN_TEMP_FILE_NAME, FILE_SOURCE_NAME (&A68G_JOB)) >= 0);
   FILE_T source = open (cmd, O_WRONLY | O_CREAT | O_TRUNC, A68G_PROTECTION);
@@ -103,9 +100,6 @@ void build_script (void)
 
 void load_script (void)
 {
-#if !defined (BUILD_A68G_COMPILER)
-  return;
-#endif
   BUFFER cmd; char ch;
   BUFCLR (cmd);
   announce_phase ("script loader");
