@@ -82,7 +82,7 @@ void genie_make_device (NODE_T * p)
     exit_genie (p, A68G_RUNTIME_ERROR);
   }
 // Fill in page_size.
-  int size = a68g_string_size (p, ref_page);
+  size_t size = a68g_string_size (p, ref_page);
   if (INITIALISED (&(A68G_PAGE_SIZE (&DEVICE (file)))) && !IS_NIL (A68G_PAGE_SIZE (&DEVICE (file)))) {
     UNBLOCK_GC_HANDLE (&A68G_PAGE_SIZE (&DEVICE (file)));
   }
@@ -176,59 +176,59 @@ plPlotter *set_up_device (NODE_T * p, A68G_FILE * f)
   }
   char *device_type = DEREF (char, &DEVICE (&DEVICE (f)));
   if (!strcmp (device_type, "X")) {
-#if defined (X_DISPLAY_MISSING)
-    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_INVALID_PARAMETER, "X plotter missing", "");
-    exit_genie (p, A68G_RUNTIME_ERROR);
-#else
+    #if defined (X_DISPLAY_MISSING)
+      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_INVALID_PARAMETER, "X plotter missing", "");
+      exit_genie (p, A68G_RUNTIME_ERROR);
+    #else
 // Supported plotter type - X Window System
-    char *z = DEREF (char, &A68G_PAGE_SIZE (&DEVICE (f))), size[BUFFER_SIZE];
+      char *z = DEREF (char, &A68G_PAGE_SIZE (&DEVICE (f))), size[BUFFER_SIZE];
 // Establish page size.
-    if (!scan_int (&z, &(WINDOW_X_SIZE (&DEVICE (f))))) {
-      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_PAGE_SIZE);
-      exit_genie (p, A68G_RUNTIME_ERROR);
-    }
-    if (!scan_int (&z, &(WINDOW_Y_SIZE (&DEVICE (f))))) {
-      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_PAGE_SIZE);
-      exit_genie (p, A68G_RUNTIME_ERROR);
-    }
-    if (z[0] != NULL_CHAR) {
-      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_PAGE_SIZE);
-      exit_genie (p, A68G_RUNTIME_ERROR);
-    }
+      if (!scan_int (&z, &(WINDOW_X_SIZE (&DEVICE (f))))) {
+        diagnostic (A68G_RUNTIME_ERROR, p, ERROR_PAGE_SIZE);
+        exit_genie (p, A68G_RUNTIME_ERROR);
+      }
+      if (!scan_int (&z, &(WINDOW_Y_SIZE (&DEVICE (f))))) {
+        diagnostic (A68G_RUNTIME_ERROR, p, ERROR_PAGE_SIZE);
+        exit_genie (p, A68G_RUNTIME_ERROR);
+      }
+      if (z[0] != NULL_CHAR) {
+        diagnostic (A68G_RUNTIME_ERROR, p, ERROR_PAGE_SIZE);
+        exit_genie (p, A68G_RUNTIME_ERROR);
+      }
 // Make the X window.
-    FD (f) = -1;
-    PLOTTER_PARAMS (&DEVICE (f)) = pl_newplparams ();
-    if (PLOTTER_PARAMS (&DEVICE (f)) == NULL) {
-      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_DEVICE_CANNOT_ALLOCATE);
-      exit_genie (p, A68G_RUNTIME_ERROR);
-    }
-    ASSERT (a68g_bufprt (size, SNPRINTF_SIZE, "%dx%d", WINDOW_X_SIZE (&DEVICE (f)), WINDOW_Y_SIZE (&DEVICE (f))) >= 0);
-    (void) pl_setplparam (PLOTTER_PARAMS (&DEVICE (f)), "BITMAPSIZE", size);
-    (void) pl_setplparam (PLOTTER_PARAMS (&DEVICE (f)), "BG_COLOR", (void *) "black");
-    (void) pl_setplparam (PLOTTER_PARAMS (&DEVICE (f)), "VANISH_ON_DELETE", (void *) "no");
-    (void) pl_setplparam (PLOTTER_PARAMS (&DEVICE (f)), "X_AUTO_FLUSH", (void *) "yes");
-    (void) pl_setplparam (PLOTTER_PARAMS (&DEVICE (f)), "USE_DOUBLE_BUFFERING", (void *) "no");
-    PLOTTER (&DEVICE (f)) = pl_newpl_r ("X", NULL, NULL, stderr, PLOTTER_PARAMS (&DEVICE (f)));
-    if (PLOTTER (&DEVICE (f)) == NULL) {
-      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_DEVICE_CANNOT_OPEN);
-      exit_genie (p, A68G_RUNTIME_ERROR);
-    }
-    if (pl_openpl_r (PLOTTER (&DEVICE (f))) < 0) {
-      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_DEVICE_CANNOT_OPEN);
-      exit_genie (p, A68G_RUNTIME_ERROR);
-    }
-    (void) pl_space_r (PLOTTER (&DEVICE (f)), 0, 0, WINDOW_X_SIZE (&DEVICE (f)), WINDOW_Y_SIZE (&DEVICE (f)));
-    (void) pl_bgcolorname_r (PLOTTER (&DEVICE (f)), "black");
-    (void) pl_colorname_r (PLOTTER (&DEVICE (f)), "white");
-    (void) pl_pencolorname_r (PLOTTER (&DEVICE (f)), "white");
-    (void) pl_fillcolorname_r (PLOTTER (&DEVICE (f)), "white");
-    (void) pl_filltype_r (PLOTTER (&DEVICE (f)), 0);
-    DRAW_MOOD (f) = A68G_TRUE;
-    DEVICE_OPENED (&DEVICE (f)) = A68G_TRUE;
-    X_COORD (&DEVICE (f)) = 0;
-    Y_COORD (&DEVICE (f)) = 0;
-    return PLOTTER (&DEVICE (f));
-#endif
+      FD (f) = A68G_NO_FILE;
+      PLOTTER_PARAMS (&DEVICE (f)) = pl_newplparams ();
+      if (PLOTTER_PARAMS (&DEVICE (f)) == NULL) {
+        diagnostic (A68G_RUNTIME_ERROR, p, ERROR_DEVICE_CANNOT_ALLOCATE);
+        exit_genie (p, A68G_RUNTIME_ERROR);
+      }
+      ASSERT (a68g_bufprt (size, SNPRINTF_SIZE, "%dx%d", WINDOW_X_SIZE (&DEVICE (f)), WINDOW_Y_SIZE (&DEVICE (f))) >= 0);
+      (void) pl_setplparam (PLOTTER_PARAMS (&DEVICE (f)), "BITMAPSIZE", size);
+      (void) pl_setplparam (PLOTTER_PARAMS (&DEVICE (f)), "BG_COLOR", (void *) "black");
+      (void) pl_setplparam (PLOTTER_PARAMS (&DEVICE (f)), "VANISH_ON_DELETE", (void *) "no");
+      (void) pl_setplparam (PLOTTER_PARAMS (&DEVICE (f)), "X_AUTO_FLUSH", (void *) "yes");
+      (void) pl_setplparam (PLOTTER_PARAMS (&DEVICE (f)), "USE_DOUBLE_BUFFERING", (void *) "no");
+      PLOTTER (&DEVICE (f)) = pl_newpl_r ("X", NULL, NULL, stderr, PLOTTER_PARAMS (&DEVICE (f)));
+      if (PLOTTER (&DEVICE (f)) == NULL) {
+        diagnostic (A68G_RUNTIME_ERROR, p, ERROR_DEVICE_CANNOT_OPEN);
+        exit_genie (p, A68G_RUNTIME_ERROR);
+      }
+      if (pl_openpl_r (PLOTTER (&DEVICE (f))) < 0) {
+        diagnostic (A68G_RUNTIME_ERROR, p, ERROR_DEVICE_CANNOT_OPEN);
+        exit_genie (p, A68G_RUNTIME_ERROR);
+      }
+      (void) pl_space_r (PLOTTER (&DEVICE (f)), 0, 0, WINDOW_X_SIZE (&DEVICE (f)), WINDOW_Y_SIZE (&DEVICE (f)));
+      (void) pl_bgcolorname_r (PLOTTER (&DEVICE (f)), "black");
+      (void) pl_colorname_r (PLOTTER (&DEVICE (f)), "white");
+      (void) pl_pencolorname_r (PLOTTER (&DEVICE (f)), "white");
+      (void) pl_fillcolorname_r (PLOTTER (&DEVICE (f)), "white");
+      (void) pl_filltype_r (PLOTTER (&DEVICE (f)), 0);
+      DRAW_MOOD (f) = A68G_TRUE;
+      DEVICE_OPENED (&DEVICE (f)) = A68G_TRUE;
+      X_COORD (&DEVICE (f)) = 0;
+      Y_COORD (&DEVICE (f)) = 0;
+      return PLOTTER (&DEVICE (f));
+    #endif
   } else if (!strcmp (device_type, "gif")) {
 // Supported plotter type - pseudo GIF
     char *z = DEREF (char, &A68G_PAGE_SIZE (&DEVICE (f))), size[BUFFER_SIZE];
@@ -348,118 +348,118 @@ plPlotter *set_up_device (NODE_T * p, A68G_FILE * f)
     Y_COORD (&DEVICE (f)) = 0;
     return PLOTTER (&DEVICE (f));
   } else if (!strcmp (device_type, "png")) {
-#if defined (X_DISPLAY_MISSING)
-    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_INVALID_PARAMETER, "PNG plotter missing", "");
-    exit_genie (p, A68G_RUNTIME_ERROR);
-#else
+    #if defined (X_DISPLAY_MISSING)
+      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_INVALID_PARAMETER, "PNG plotter missing", "");
+      exit_genie (p, A68G_RUNTIME_ERROR);
+    #else
 // Supported plotter type - PNG
-    char *z = DEREF (char, &A68G_PAGE_SIZE (&DEVICE (f))), size[BUFFER_SIZE];
+      char *z = DEREF (char, &A68G_PAGE_SIZE (&DEVICE (f))), size[BUFFER_SIZE];
 // Establish page size.
-    if (!scan_int (&z, &(WINDOW_X_SIZE (&DEVICE (f))))) {
-      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_PAGE_SIZE);
-      exit_genie (p, A68G_RUNTIME_ERROR);
-    }
-    if (!scan_int (&z, &(WINDOW_Y_SIZE (&DEVICE (f))))) {
-      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_PAGE_SIZE);
-      exit_genie (p, A68G_RUNTIME_ERROR);
-    }
-    if (z[0] != NULL_CHAR) {
-      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_PAGE_SIZE);
-      exit_genie (p, A68G_RUNTIME_ERROR);
-    }
+      if (!scan_int (&z, &(WINDOW_X_SIZE (&DEVICE (f))))) {
+        diagnostic (A68G_RUNTIME_ERROR, p, ERROR_PAGE_SIZE);
+        exit_genie (p, A68G_RUNTIME_ERROR);
+      }
+      if (!scan_int (&z, &(WINDOW_Y_SIZE (&DEVICE (f))))) {
+        diagnostic (A68G_RUNTIME_ERROR, p, ERROR_PAGE_SIZE);
+        exit_genie (p, A68G_RUNTIME_ERROR);
+      }
+      if (z[0] != NULL_CHAR) {
+        diagnostic (A68G_RUNTIME_ERROR, p, ERROR_PAGE_SIZE);
+        exit_genie (p, A68G_RUNTIME_ERROR);
+      }
 // Open the output file for drawing.
-    CHECK_REF (p, ref_filename, M_ROWS);
-    char *filename = DEREF (char, &ref_filename);
-    errno = 0;
-    if ((STREAM (&DEVICE (f)) = fopen (filename, "wb")) == NO_STREAM) {
-      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_CANNOT_OPEN_NAME, filename);
-      exit_genie (p, A68G_RUNTIME_ERROR);
-    } else {
-      READ_MOOD (f) = A68G_FALSE;
-      WRITE_MOOD (f) = A68G_FALSE;
-      CHAR_MOOD (f) = A68G_FALSE;
-      DRAW_MOOD (f) = A68G_TRUE;
-    }
+      CHECK_REF (p, ref_filename, M_ROWS);
+      char *filename = DEREF (char, &ref_filename);
+      errno = 0;
+      if ((STREAM (&DEVICE (f)) = fopen (filename, "wb")) == NO_STREAM) {
+        diagnostic (A68G_RUNTIME_ERROR, p, ERROR_CANNOT_OPEN_NAME, filename);
+        exit_genie (p, A68G_RUNTIME_ERROR);
+      } else {
+        READ_MOOD (f) = A68G_FALSE;
+        WRITE_MOOD (f) = A68G_FALSE;
+        CHAR_MOOD (f) = A68G_FALSE;
+        DRAW_MOOD (f) = A68G_TRUE;
+      }
 // Set up plotter.
-    PLOTTER_PARAMS (&DEVICE (f)) = pl_newplparams ();
-    if (PLOTTER_PARAMS (&DEVICE (f)) == NULL) {
-      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_DEVICE_CANNOT_ALLOCATE);
-      exit_genie (p, A68G_RUNTIME_ERROR);
-    }
-    ASSERT (a68g_bufprt (size, SNPRINTF_SIZE, "%dx%d", WINDOW_X_SIZE (&DEVICE (f)), WINDOW_Y_SIZE (&DEVICE (f))) >= 0);
-    (void) pl_setplparam (PLOTTER_PARAMS (&DEVICE (f)), "BITMAPSIZE", size);
-    (void) pl_setplparam (PLOTTER_PARAMS (&DEVICE (f)), "BG_COLOR", (void *) "black");
-    (void) pl_setplparam (PLOTTER_PARAMS (&DEVICE (f)), "GIF_ANIMATION", (void *) "no");
-    PLOTTER (&DEVICE (f)) = pl_newpl_r ("png", NULL, STREAM (&DEVICE (f)), stderr, PLOTTER_PARAMS (&DEVICE (f)));
-    if (PLOTTER (&DEVICE (f)) == NULL) {
-      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_DEVICE_CANNOT_OPEN);
-      exit_genie (p, A68G_RUNTIME_ERROR);
-    }
-    if (pl_openpl_r (PLOTTER (&DEVICE (f))) < 0) {
-      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_DEVICE_CANNOT_OPEN);
-      exit_genie (p, A68G_RUNTIME_ERROR);
-    }
-    (void) pl_space_r (PLOTTER (&DEVICE (f)), 0, 0, WINDOW_X_SIZE (&DEVICE (f)), WINDOW_Y_SIZE (&DEVICE (f)));
-    (void) pl_bgcolorname_r (PLOTTER (&DEVICE (f)), "black");
-    (void) pl_colorname_r (PLOTTER (&DEVICE (f)), "white");
-    (void) pl_pencolorname_r (PLOTTER (&DEVICE (f)), "white");
-    (void) pl_fillcolorname_r (PLOTTER (&DEVICE (f)), "white");
-    (void) pl_filltype_r (PLOTTER (&DEVICE (f)), 0);
-    DRAW_MOOD (f) = A68G_TRUE;
-    DEVICE_OPENED (&DEVICE (f)) = A68G_TRUE;
-    X_COORD (&DEVICE (f)) = 0;
-    Y_COORD (&DEVICE (f)) = 0;
-    return PLOTTER (&DEVICE (f));
-#endif
+      PLOTTER_PARAMS (&DEVICE (f)) = pl_newplparams ();
+      if (PLOTTER_PARAMS (&DEVICE (f)) == NULL) {
+        diagnostic (A68G_RUNTIME_ERROR, p, ERROR_DEVICE_CANNOT_ALLOCATE);
+        exit_genie (p, A68G_RUNTIME_ERROR);
+      }
+      ASSERT (a68g_bufprt (size, SNPRINTF_SIZE, "%dx%d", WINDOW_X_SIZE (&DEVICE (f)), WINDOW_Y_SIZE (&DEVICE (f))) >= 0);
+      (void) pl_setplparam (PLOTTER_PARAMS (&DEVICE (f)), "BITMAPSIZE", size);
+      (void) pl_setplparam (PLOTTER_PARAMS (&DEVICE (f)), "BG_COLOR", (void *) "black");
+      (void) pl_setplparam (PLOTTER_PARAMS (&DEVICE (f)), "GIF_ANIMATION", (void *) "no");
+      PLOTTER (&DEVICE (f)) = pl_newpl_r ("png", NULL, STREAM (&DEVICE (f)), stderr, PLOTTER_PARAMS (&DEVICE (f)));
+      if (PLOTTER (&DEVICE (f)) == NULL) {
+        diagnostic (A68G_RUNTIME_ERROR, p, ERROR_DEVICE_CANNOT_OPEN);
+        exit_genie (p, A68G_RUNTIME_ERROR);
+      }
+      if (pl_openpl_r (PLOTTER (&DEVICE (f))) < 0) {
+        diagnostic (A68G_RUNTIME_ERROR, p, ERROR_DEVICE_CANNOT_OPEN);
+        exit_genie (p, A68G_RUNTIME_ERROR);
+      }
+      (void) pl_space_r (PLOTTER (&DEVICE (f)), 0, 0, WINDOW_X_SIZE (&DEVICE (f)), WINDOW_Y_SIZE (&DEVICE (f)));
+      (void) pl_bgcolorname_r (PLOTTER (&DEVICE (f)), "black");
+      (void) pl_colorname_r (PLOTTER (&DEVICE (f)), "white");
+      (void) pl_pencolorname_r (PLOTTER (&DEVICE (f)), "white");
+      (void) pl_fillcolorname_r (PLOTTER (&DEVICE (f)), "white");
+      (void) pl_filltype_r (PLOTTER (&DEVICE (f)), 0);
+      DRAW_MOOD (f) = A68G_TRUE;
+      DEVICE_OPENED (&DEVICE (f)) = A68G_TRUE;
+      X_COORD (&DEVICE (f)) = 0;
+      Y_COORD (&DEVICE (f)) = 0;
+      return PLOTTER (&DEVICE (f));
+    #endif
   } else if (!strcmp (device_type, "ps")) {
-#if defined (POSTSCRIPT_MISSING)
-    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_INVALID_PARAMETER, "postscript plotter missing", "");
-    exit_genie (p, A68G_RUNTIME_ERROR);
-#else
+    #if defined (POSTSCRIPT_MISSING)
+      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_INVALID_PARAMETER, "postscript plotter missing", "");
+      exit_genie (p, A68G_RUNTIME_ERROR);
+    #else
 // Supported plotter type - Postscript
 // Open the output file for drawing.
-    CHECK_REF (p, ref_filename, M_ROWS);
-    char *filename = DEREF (char, &ref_filename);
-    errno = 0;
-    if ((STREAM (&DEVICE (f)) = fopen (filename, "w")) == NO_STREAM) {
-      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_CANNOT_OPEN_NAME, filename);
-      exit_genie (p, A68G_RUNTIME_ERROR);
-    } else {
-      READ_MOOD (f) = A68G_FALSE;
-      WRITE_MOOD (f) = A68G_FALSE;
-      CHAR_MOOD (f) = A68G_FALSE;
-      DRAW_MOOD (f) = A68G_TRUE;
-    }
+      CHECK_REF (p, ref_filename, M_ROWS);
+      char *filename = DEREF (char, &ref_filename);
+      errno = 0;
+      if ((STREAM (&DEVICE (f)) = fopen (filename, "w")) == NO_STREAM) {
+        diagnostic (A68G_RUNTIME_ERROR, p, ERROR_CANNOT_OPEN_NAME, filename);
+        exit_genie (p, A68G_RUNTIME_ERROR);
+      } else {
+        READ_MOOD (f) = A68G_FALSE;
+        WRITE_MOOD (f) = A68G_FALSE;
+        CHAR_MOOD (f) = A68G_FALSE;
+        DRAW_MOOD (f) = A68G_TRUE;
+      }
 // Set up ps plotter.
-    PLOTTER_PARAMS (&DEVICE (f)) = pl_newplparams ();
-    if (PLOTTER_PARAMS (&DEVICE (f)) == NULL) {
-      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_DEVICE_CANNOT_ALLOCATE);
-      exit_genie (p, A68G_RUNTIME_ERROR);
-    }
-    (void) pl_setplparam (PLOTTER_PARAMS (&DEVICE (f)), "PAGESIZE", DEREF (char, &A68G_PAGE_SIZE (&DEVICE (f))));
-    PLOTTER (&DEVICE (f)) = pl_newpl_r ("ps", NULL, STREAM (&DEVICE (f)), stderr, PLOTTER_PARAMS (&DEVICE (f)));
-    if (PLOTTER (&DEVICE (f)) == NULL) {
-      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_DEVICE_CANNOT_OPEN);
-      exit_genie (p, A68G_RUNTIME_ERROR);
-    }
-    if (pl_openpl_r (PLOTTER (&DEVICE (f))) < 0) {
-      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_DEVICE_CANNOT_OPEN);
-      exit_genie (p, A68G_RUNTIME_ERROR);
-    }
-    WINDOW_X_SIZE (&DEVICE (f)) = 1000;
-    WINDOW_Y_SIZE (&DEVICE (f)) = 1000;
-    (void) pl_space_r (PLOTTER (&DEVICE (f)), 0, 0, WINDOW_X_SIZE (&DEVICE (f)), WINDOW_Y_SIZE (&DEVICE (f)));
-    (void) pl_bgcolorname_r (PLOTTER (&DEVICE (f)), "black");
-    (void) pl_colorname_r (PLOTTER (&DEVICE (f)), "white");
-    (void) pl_pencolorname_r (PLOTTER (&DEVICE (f)), "white");
-    (void) pl_fillcolorname_r (PLOTTER (&DEVICE (f)), "white");
-    (void) pl_filltype_r (PLOTTER (&DEVICE (f)), 0);
-    DRAW_MOOD (f) = A68G_TRUE;
-    DEVICE_OPENED (&DEVICE (f)) = A68G_TRUE;
-    X_COORD (&DEVICE (f)) = 0;
-    Y_COORD (&DEVICE (f)) = 0;
-    return PLOTTER (&DEVICE (f));
-#endif
+      PLOTTER_PARAMS (&DEVICE (f)) = pl_newplparams ();
+      if (PLOTTER_PARAMS (&DEVICE (f)) == NULL) {
+        diagnostic (A68G_RUNTIME_ERROR, p, ERROR_DEVICE_CANNOT_ALLOCATE);
+        exit_genie (p, A68G_RUNTIME_ERROR);
+      }
+      (void) pl_setplparam (PLOTTER_PARAMS (&DEVICE (f)), "PAGESIZE", DEREF (char, &A68G_PAGE_SIZE (&DEVICE (f))));
+      PLOTTER (&DEVICE (f)) = pl_newpl_r ("ps", NULL, STREAM (&DEVICE (f)), stderr, PLOTTER_PARAMS (&DEVICE (f)));
+      if (PLOTTER (&DEVICE (f)) == NULL) {
+        diagnostic (A68G_RUNTIME_ERROR, p, ERROR_DEVICE_CANNOT_OPEN);
+        exit_genie (p, A68G_RUNTIME_ERROR);
+      }
+      if (pl_openpl_r (PLOTTER (&DEVICE (f))) < 0) {
+        diagnostic (A68G_RUNTIME_ERROR, p, ERROR_DEVICE_CANNOT_OPEN);
+        exit_genie (p, A68G_RUNTIME_ERROR);
+      }
+      WINDOW_X_SIZE (&DEVICE (f)) = 1000;
+      WINDOW_Y_SIZE (&DEVICE (f)) = 1000;
+      (void) pl_space_r (PLOTTER (&DEVICE (f)), 0, 0, WINDOW_X_SIZE (&DEVICE (f)), WINDOW_Y_SIZE (&DEVICE (f)));
+      (void) pl_bgcolorname_r (PLOTTER (&DEVICE (f)), "black");
+      (void) pl_colorname_r (PLOTTER (&DEVICE (f)), "white");
+      (void) pl_pencolorname_r (PLOTTER (&DEVICE (f)), "white");
+      (void) pl_fillcolorname_r (PLOTTER (&DEVICE (f)), "white");
+      (void) pl_filltype_r (PLOTTER (&DEVICE (f)), 0);
+      DRAW_MOOD (f) = A68G_TRUE;
+      DEVICE_OPENED (&DEVICE (f)) = A68G_TRUE;
+      X_COORD (&DEVICE (f)) = 0;
+      Y_COORD (&DEVICE (f)) = 0;
+      return PLOTTER (&DEVICE (f));
+    #endif
   } else {
     diagnostic (A68G_RUNTIME_ERROR, p, ERROR_INVALID_PARAMETER, "unindentified plotter", device_type);
     exit_genie (p, A68G_RUNTIME_ERROR);
@@ -630,7 +630,7 @@ void genie_draw_linestyle (NODE_T * p)
   CHECK_REF (p, ref_file, M_REF_FILE);
   A68G_FILE *f = FILE_DEREF (&ref_file);
   plPlotter *plotter = set_up_device (p, f);
-  int size = a68g_string_size (p, txt);
+  size_t size = a68g_string_size (p, txt);
   A68G_REF z_ref = heap_generator (p, M_C_STRING, 1 + size);
   char *z = DEREF (char, &z_ref);
   ASSERT (a_to_c_string (p, z, txt) != NO_TEXT);
@@ -798,7 +798,7 @@ void genie_draw_text (NODE_T * p)
   CHECK_REF (p, ref_file, M_REF_FILE);
   A68G_FILE *f = FILE_DEREF (&ref_file);
   plPlotter *plotter = set_up_device (p, f);
-  int size = a68g_string_size (p, txt);
+  size_t size = a68g_string_size (p, txt);
   A68G_REF z_ref = heap_generator (p, M_C_STRING, 1 + size);
   char *z = DEREF (char, &z_ref);
   ASSERT (a_to_c_string (p, z, txt) != NO_TEXT);
@@ -815,7 +815,7 @@ void genie_draw_fontname (NODE_T * p)
   CHECK_REF (p, ref_file, M_REF_FILE);
   A68G_FILE *f = FILE_DEREF (&ref_file);
   plPlotter *plotter = set_up_device (p, f);
-  int size = a68g_string_size (p, txt);
+  size_t size = a68g_string_size (p, txt);
   A68G_REF z_ref = heap_generator (p, M_C_STRING, 1 + size);
   char *z = DEREF (char, &z_ref);
   ASSERT (a_to_c_string (p, z, txt) != NO_TEXT);
@@ -1531,7 +1531,7 @@ const colour_info A68G_COLOURS[COLOUR_NAMES + 1] = {
 
 BOOL_T string_to_colour (NODE_T * p, char *name, int *pos)
 {
-  A68G_REF z_ref = heap_generator (p, M_C_STRING, (int) (1 + strlen (name)));
+  A68G_REF z_ref = heap_generator (p, M_C_STRING, 1 + strlen (name));
   char *z = DEREF (char, &z_ref);
 // First remove formatting from name: spaces and capitals are irrelevant.
   int j = 0;
