@@ -49,7 +49,7 @@ size_t get_row_size (A68G_TUPLE * tup, int dim)
   size_t span = 1;
   for (int k = 0; k < dim; k++) {
     size_t stride = ROW_SIZE (&tup[k]);
-    ABEND ((stride > 0 && span > A68G_MAX_INT / stride), ERROR_INVALID_SIZE, __func__);
+    ABEND ((stride > 0 && span > A68G_MAX_INT / stride), ERROR_INVALID_SIZE, NO_TEXT);
     span *= stride;
   }
   return span;
