@@ -34,12 +34,12 @@
 static void laplace_error_handler (const char *reason, const char *file, int line, int gsl_errno)
 {
   if (line != 0) {
-    ASSERT (a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "%s in line %d of file %s", reason, line, file) >= 0);
+    ASSERT (a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "%s in line %d of file %s", reason, line, file) >= 0);
   } else {
-    ASSERT (a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "%s", reason) >= 0);
+    ASSERT (a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "%s", reason) >= 0);
   }
-  diagnostic (A68_RUNTIME_ERROR, A68 (f_entry), ERROR_LAPLACE, A68 (edit_line), gsl_strerror (gsl_errno));
-  exit_genie (A68 (f_entry), A68_RUNTIME_ERROR);
+  diagnostic (A68G_RUNTIME_ERROR, A68G (f_entry), ERROR_LAPLACE, A68G (edit_line), gsl_strerror (gsl_errno));
+  exit_genie (A68G (f_entry), A68G_RUNTIME_ERROR);
 }
 
 //! @brief Detect math errors.
@@ -55,12 +55,12 @@ static void laplace_test_error (int ret)
 
 #define LAPLACE_DIVISIONS 1024
 
-typedef struct A68_LAPLACE A68_LAPLACE;
+typedef struct A68G_LAPLACE A68G_LAPLACE;
 
-struct A68_LAPLACE
+struct A68G_LAPLACE
 {
   NODE_T *p;
-  A68_PROCEDURE f;
+  A68G_PROCEDURE f;
   REAL_T s;
 };
 
@@ -68,13 +68,13 @@ struct A68_LAPLACE
 
 static REAL_T laplace_f (REAL_T t, void *z)
 {
-  A68_LAPLACE *l = (A68_LAPLACE *) z;
-  ADDR_T pop_sp = A68_SP, pop_fp = A68_FP;
+  A68G_LAPLACE *l = (A68G_LAPLACE *) z;
+  ADDR_T pop_sp = A68G_SP, pop_fp = A68G_FP;
   MOID_T *u = M_PROC_REAL_REAL;
-  A68_REAL *ft = (A68_REAL *) STACK_TOP;
-  PUSH_VALUE (P (l), t, A68_REAL);
+  A68G_REAL *ft = (A68G_REAL *) STACK_TOP;
+  PUSH_VALUE (P (l), t, A68G_REAL);
   genie_call_procedure (P (l), MOID (&(F (l))), u, u, &(F (l)), pop_sp, pop_fp);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return VALUE (ft) * a68g_exp_real (-(S (l)) * t);
 }
 
@@ -83,15 +83,15 @@ static REAL_T laplace_f (REAL_T t, void *z)
 void genie_laplace (NODE_T * p)
 {
   gsl_error_handler_t *save_handler = gsl_set_error_handler (laplace_error_handler);
-  A68_REF ref_err;
+  A68G_REF ref_err;
   POP_REF (p, &ref_err);
   CHECK_REF (p, ref_err, M_REF_REAL);
-  A68_REAL *err = (A68_REAL *) ADDRESS (&ref_err);
-  A68_REAL s;
-  POP_OBJECT (p, &s, A68_REAL);
-  A68_PROCEDURE f;
+  A68G_REAL *err = (A68G_REAL *) ADDRESS (&ref_err);
+  A68G_REAL s;
+  POP_OBJECT (p, &s, A68G_REAL);
+  A68G_PROCEDURE f;
   POP_PROCEDURE (p, &f);
-  A68_LAPLACE l;
+  A68G_LAPLACE l;
   P (&l) = p;
   F (&l) = f;
   S (&l) = VALUE (&s);
@@ -107,7 +107,7 @@ void genie_laplace (NODE_T * p)
   }
   laplace_test_error (ret);
   VALUE (err) = estimated_err;
-  PUSH_VALUE (p, res, A68_REAL);
+  PUSH_VALUE (p, res, A68G_REAL);
   gsl_integration_workspace_free (w);
   (void) gsl_set_error_handler (save_handler);
 }
