@@ -486,17 +486,14 @@ void genie_matrix_complex_det (NODE_T * p)
   gsl_permutation *q = gsl_permutation_calloc (SIZE1 (u));
   int sign, rc = gsl_linalg_complex_LU_decomp (u, q, &sign);
   if (rc != GSL_SUCCESS) {
-    PUSH_VALUE (p, 0, A68G_REAL);
-    PUSH_VALUE (p, 0, A68G_REAL);
+    PUSH_COMPLEX_VALUE (p, 0, 0);
   } else {
     gsl_complex det = gsl_linalg_complex_LU_det (u, sign);
     REAL_T re_det = GSL_REAL (det), im_det = GSL_IMAG (det);
     if (a68g_isnan_real (re_det) || a68g_isnan_real (im_det)) {
-      PUSH_VALUE (p, 0, A68G_REAL);
-      PUSH_VALUE (p, 0, A68G_REAL);
+      PUSH_COMPLEX_VALUE (p, 0, 0);
     } else {
-      PUSH_VALUE (p, re_det, A68G_REAL);
-      PUSH_VALUE (p, im_det, A68G_REAL);
+      PUSH_COMPLEX_VALUE (p, re_det, im_det);
     }
   }
   gsl_matrix_complex_free (u);
@@ -538,8 +535,7 @@ void genie_matrix_complex_trace (NODE_T * p)
   for (int k = 0; k < len1; k++) {
     sum = gsl_complex_add (sum, gsl_matrix_complex_get (a, (size_t) k, (size_t) k));
   }
-  PUSH_VALUE (p, GSL_REAL (sum), A68G_REAL);
-  PUSH_VALUE (p, GSL_IMAG (sum), A68G_REAL);
+  PUSH_COMPLEX_VALUE (p, GSL_REAL (sum), GSL_IMAG (sum));
   gsl_matrix_complex_free (a);
   (void) gsl_set_error_handler (save_handler);
 }
@@ -1110,8 +1106,7 @@ void genie_vector_complex_dot (NODE_T * p)
   gsl_vector_complex *u = pop_vector_complex (p, A68G_TRUE);
   gsl_complex w;
   ASSERT_GSL (gsl_blas_zdotc (u, v, &w));
-  PUSH_VALUE (p, GSL_REAL (w), A68G_REAL);
-  PUSH_VALUE (p, GSL_IMAG (w), A68G_REAL);
+  PUSH_COMPLEX_VALUE (p, GSL_REAL (w), GSL_IMAG (w));
   gsl_vector_complex_free (u);
   gsl_vector_complex_free (v);
   (void) gsl_set_error_handler (save_handler);
