@@ -26,6 +26,8 @@
 #if !defined (__A68G_GENIE_H__)
 #define __A68G_GENIE_H__
 
+#include "a68g-frames.h"
+
 //! @brief PROC VOID gc heap
 
 // Prelude errors can also occur in the constant folder
@@ -35,17 +37,17 @@
 
 #define CHECK_INT_ADDITION(p, i, j)\
   PRELUDE_ERROR (\
-    ((j) > 0 && (i) > (A68_MAX_INT - (j))) || ((j) < 0 && (i) < (-A68_MAX_INT - (j))),\
+    ((j) > 0 && (i) > (A68G_MAX_INT - (j))) || ((j) < 0 && (i) < (-A68G_MAX_INT - (j))),\
     p, "M overflow", M_INT)
 
 #define CHECK_INT_MULTIPLICATION(p, i, j)\
   PRELUDE_ERROR (\
-    (j) != 0 && ABS (i) > A68_MAX_INT / ABS (j),\
+    (j) != 0 && ABS (i) > A68G_MAX_INT / ABS (j),\
     p, "M overflow", M_INT)
 
 #define CHECK_BITS_ADDITION(p, i, j)\
   if (!MODULAR_MATH (p)) {\
-    PRELUDE_ERROR (((i) > (A68_MAX_BITS - (j))), p, ERROR_MATH, M_BITS);\
+    PRELUDE_ERROR (((i) > (A68G_MAX_BITS - (j))), p, ERROR_MATH, M_BITS);\
   }
 
 #define CHECK_BITS_SUBTRACTION(p, i, j)\
@@ -55,7 +57,7 @@
 
 #define CHECK_BITS_MULTIPLICATION(p, i, j)\
   if (!MODULAR_MATH (p)) {\
-    PRELUDE_ERROR ((j) != 0 && (i) > A68_MAX_BITS / (j), p, ERROR_MATH, M_BITS);\
+    PRELUDE_ERROR ((j) != 0 && (i) > A68G_MAX_BITS / (j), p, ERROR_MATH, M_BITS);\
   }
 
 #define CHECK_INT_DIVISION(p, i, j)\
@@ -63,38 +65,38 @@
 
 #define PRELUDE_ERROR(cond, p, txt, add)\
   if (cond) {\
-    if (A68 (in_execution)) {\
-      diagnostic (A68_RUNTIME_ERROR, p, txt, add);\
-      exit_genie (p, A68_RUNTIME_ERROR);\
+    if (A68G (in_execution)) {\
+      diagnostic (A68G_RUNTIME_ERROR, p, txt, add);\
+      exit_genie (p, A68G_RUNTIME_ERROR);\
     } else {\
-      diagnostic (A68_MATH_ERROR, p, txt, add);\
+      diagnostic (A68G_MATH_ERROR, p, txt, add);\
     }}
 
 // Check on a NIL name
 
 #define CHECK_REF(p, z, m)\
   if (! INITIALISED (&z)) {\
-    diagnostic (A68_RUNTIME_ERROR, (p), ERROR_EMPTY_VALUE_FROM, (m));\
-    exit_genie ((p), A68_RUNTIME_ERROR);\
+    diagnostic (A68G_RUNTIME_ERROR, (p), ERROR_EMPTY_VALUE_FROM, (m));\
+    exit_genie ((p), A68G_RUNTIME_ERROR);\
   } else if (IS_NIL (z)) {\
-    diagnostic (A68_RUNTIME_ERROR, (p), ERROR_ACCESSING_NIL, (m));\
-    exit_genie ((p), A68_RUNTIME_ERROR);\
+    diagnostic (A68G_RUNTIME_ERROR, (p), ERROR_ACCESSING_NIL, (m));\
+    exit_genie ((p), A68G_RUNTIME_ERROR);\
   }
 
 // Macros for row-handling
 
 // An A68G row is a reference to a descriptor in the heap:
-// A68_REF row -> A68_ARRAY ----+   ARRAY: Description of row, ref to elements.
-//                A68_TUPLE 1   |   TUPLE: Bounds, one for every dimension.
+// A68G_REF row -> A68G_ARRAY ----+   ARRAY: Description of row, ref to elements.
+//                A68G_TUPLE 1   |   TUPLE: Bounds, one for every dimension.
 //                ...           |
-//                A68_TUPLE dim |
+//                A68G_TUPLE dim |
 //                ...           |
 //                ...           |
 //                Element 1 <---+   Sequential row elements in the heap.
 //                ...
 //                Element n
 
-#define DESCRIPTOR_SIZE(n) (SIZE_ALIGNED (A68_ARRAY) + (n) * SIZE_ALIGNED (A68_TUPLE))
+#define DESCRIPTOR_SIZE(n) (SIZE_ALIGNED (A68G_ARRAY) + (n) * SIZE_ALIGNED (A68G_TUPLE))
 
 #define NEW_ROW_1D(des, row, arr, tup, row_m, mod, upb)\
   (des) = heap_generator (p, (row_m), DESCRIPTOR_SIZE (1));\
@@ -113,25 +115,25 @@
   PUT_DESCRIPTOR ((arr), (tup), &(des));
 
 #define GET_DESCRIPTOR(arr, tup, p)\
-  arr = (A68_ARRAY *) ARRAY_ADDRESS (p);\
-  tup = (A68_TUPLE *) & (((BYTE_T *) (arr)) [SIZE_ALIGNED (A68_ARRAY)]);
+  arr = (A68G_ARRAY *) ARRAY_ADDRESS (p);\
+  tup = (A68G_TUPLE *) & (((BYTE_T *) (arr)) [SIZE_ALIGNED (A68G_ARRAY)]);
 
 #define GET_DESCRIPTOR2(arr, tup1, tup2, p)\
-  arr = (A68_ARRAY *) ARRAY_ADDRESS (p);\
-  tup1 = (A68_TUPLE *) & (((BYTE_T *) (arr)) [SIZE_ALIGNED (A68_ARRAY)]);\
-  tup2 = (A68_TUPLE *) & (((BYTE_T *) (arr)) [SIZE_ALIGNED (A68_ARRAY) + sizeof (A68_TUPLE)]);
+  arr = (A68G_ARRAY *) ARRAY_ADDRESS (p);\
+  tup1 = (A68G_TUPLE *) & (((BYTE_T *) (arr)) [SIZE_ALIGNED (A68G_ARRAY)]);\
+  tup2 = (A68G_TUPLE *) & (((BYTE_T *) (arr)) [SIZE_ALIGNED (A68G_ARRAY) + sizeof (A68G_TUPLE)]);
 
 #define PUT_DESCRIPTOR(arr, tup, p) {\
   BYTE_T *a_p = ARRAY_ADDRESS (p);\
-  *(A68_ARRAY *) a_p = (arr);\
-  *(A68_TUPLE *) &(((BYTE_T *) (a_p)) [SIZE_ALIGNED (A68_ARRAY)]) = (tup);\
+  *(A68G_ARRAY *) a_p = (arr);\
+  *(A68G_TUPLE *) &(((BYTE_T *) (a_p)) [SIZE_ALIGNED (A68G_ARRAY)]) = (tup);\
   }
 
 #define PUT_DESCRIPTOR2(arr, tup1, tup2, p) {\
   BYTE_T *a_p = ARRAY_ADDRESS (p);\
-  *(A68_ARRAY *) a_p = (arr);\
-  *(A68_TUPLE *) &(((BYTE_T *) (a_p)) [SIZE_ALIGNED (A68_ARRAY)]) = (tup1);\
-  *(A68_TUPLE *) &(((BYTE_T *) (a_p)) [SIZE_ALIGNED (A68_ARRAY) + sizeof (A68_TUPLE)]) = (tup2);\
+  *(A68G_ARRAY *) a_p = (arr);\
+  *(A68G_TUPLE *) &(((BYTE_T *) (a_p)) [SIZE_ALIGNED (A68G_ARRAY)]) = (tup1);\
+  *(A68G_TUPLE *) &(((BYTE_T *) (a_p)) [SIZE_ALIGNED (A68G_ARRAY) + sizeof (A68G_TUPLE)]) = (tup2);\
   }
 
 #define ROW_SIZE(tup) ((LWB (tup) <= UPB (tup)) ? (UPB (tup) - LWB (tup) + 1) : 0)
@@ -146,23 +148,44 @@
 
 // Execution
 
-#define GENIE_UNIT_2(p, dest) {\
-  PROP_T *_prop_ = &GPROP (p);\
-  dest = (*(UNIT (_prop_))) (SOURCE (_prop_));}
-
-#define GENIE_UNIT_NO_GC_2(p, dest) {\
-  A68_GC (sema) ++;\
-  GENIE_UNIT_2 ((p), (dest));\
-  A68_GC (sema) --;}
+#define STORE_GC(p, _sp_) {\
+  A68G_REF _loc_;\
+  STATUS (&_loc_) = (STATUS_MASK_T) (INIT_MASK | IN_FRAME_MASK);\
+  REF_HANDLE (&_loc_) = (A68G_HANDLE *) & nil_handle;\
+  OFFSET (&_loc_) = A68G_FP + FRAME_INFO_SIZE + OFFSET (TAX_GC (p));\
+  REF_SCOPE (&_loc_) = A68G_FP;\
+  COPY_ALIGNED ((BYTE_T *) ADDRESS (&_loc_), STACK_ADDRESS (_sp_), SIZE (MOID (p)));\
+}
 
 #define GENIE_UNIT(p) {\
   PROP_T *_prop_ = &GPROP (p);\
-  (void) (*(UNIT (_prop_))) (SOURCE (_prop_));}
+  if (TAX_GC (p) != NO_TAG) {\
+    ADDR_T _sp_ = A68G_SP;\
+    (void) (*(UNIT (_prop_))) (SOURCE (_prop_));\
+    STORE_GC (p, _sp_);\
+  } else {\
+    (void) (*(UNIT (_prop_))) (SOURCE (_prop_));\
+  }}
+
+#define GENIE_UNIT_KEEP(p, dest) {\
+  PROP_T *_prop_ = &GPROP (p);\
+  if (TAX_GC (p) != NO_TAG) {\
+    ADDR_T _sp_ = A68G_SP;\
+    dest = (*(UNIT (_prop_))) (SOURCE (_prop_));\
+    STORE_GC (p, _sp_);\
+  } else {\
+    dest = (*(UNIT (_prop_))) (SOURCE (_prop_));\
+  }}
 
 #define GENIE_UNIT_NO_GC(p) {\
-  A68_GC (sema) ++;\
+  A68G_GC (sema) ++;\
   GENIE_UNIT ((p));\
-  A68_GC (sema) --;}
+  A68G_GC (sema) --;}
+
+#define GENIE_UNIT_KEEP_NO_GC(p, dest) {\
+  A68G_GC (sema) ++;\
+  GENIE_UNIT_KEEP ((p), (dest));\
+  A68G_GC (sema) --;}
 
 #define GENIE_UNIT_TRACE(p) {\
   if (STATUS_TEST (p, (BREAKPOINT_MASK | BREAKPOINT_TEMPORARY_MASK | \
@@ -173,9 +196,7 @@
 
 // Stuff for the garbage collector
 
-// Check whether the heap fills
-
-#define DEFAULT_PREEMPTIVE 0.8
+#define PREEMPTIVE_FRACTION 0.9
 
 // Save a handle from the GC
 
@@ -193,8 +214,8 @@
 
 #define CHECK_INDEX(p, k, t) {\
   if (VALUE (k) < LWB (t) || VALUE (k) > UPB (t)) {\
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_INDEX_OUT_OF_BOUNDS);\
-    exit_genie (p, A68_RUNTIME_ERROR);\
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_INDEX_OUT_OF_BOUNDS);\
+    exit_genie (p, A68G_RUNTIME_ERROR);\
   }}
 
 // Tests for objects of mode REAL
@@ -212,31 +233,31 @@
 // Macros.
 
 #define C_FUNCTION(p, f)\
-  A68_REAL *x;\
-  POP_OPERAND_ADDRESS (p, x, A68_REAL);\
+  A68G_REAL *x;\
+  POP_OPERAND_ADDRESS (p, x, A68G_REAL);\
   errno = 0;\
   VALUE (x) = f (VALUE (x));\
   MATH_RTE (p, errno != 0, M_REAL, NO_TEXT);
 
 #define OWN_FUNCTION(p, f)\
-  A68_REAL *x;\
-  POP_OPERAND_ADDRESS (p, x, A68_REAL);\
+  A68G_REAL *x;\
+  POP_OPERAND_ADDRESS (p, x, A68G_REAL);\
   errno = 0;\
   VALUE (x) = f (p, VALUE (x));\
   MATH_RTE (p, errno != 0, M_REAL, NO_TEXT);
 
 // Macros for standard environ
 
-#define A68_ENV_INT(n, k) void n (NODE_T *p) {PUSH_PRIMAL (p, (k), INT);}
-#define A68_ENV_REAL(n, z) void n (NODE_T *p) {PUSH_PRIMAL (p, (z), REAL);}
+#define A68G_ENV_INT(n, k) void n (NODE_T *p) {PUSH_VALUE (p, (k), A68G_INT);}
+#define A68G_ENV_REAL(n, z) void n (NODE_T *p) {PUSH_VALUE (p, (z), A68G_REAL);}
 
 // Macros for the evaluation stack
 
 #define INCREMENT_STACK_POINTER(err, i)\
-  {A68_SP += (ADDR_T) A68_ALIGN (i); (void) (err);}
+  {A68G_SP += (ADDR_T) A68G_ALIGN (i); (void) (err);}
 
 #define DECREMENT_STACK_POINTER(err, i)\
-  {A68_SP -= A68_ALIGN (i); (void) (err);}
+  {A68G_SP -= A68G_ALIGN (i); (void) (err);}
 
 #define PUSH(p, addr, size) {\
   BYTE_T *_sp_ = STACK_TOP;\
@@ -284,14 +305,6 @@
   INCREMENT_STACK_POINTER ((p), SIZE_ALIGNED (mode));\
   }
 
-#define PUSH_PRIMAL(p, z, m) {\
-  A68_##m *_x_ = (A68_##m *) STACK_TOP;\
-  int _size_ = SIZE_ALIGNED (A68_##m);\
-  STATUS (_x_) = INIT_MASK;\
-  VALUE (_x_) = (z);\
-  INCREMENT_STACK_POINTER ((p), _size_);\
-  }
-
 #define PUSH_OBJECT(p, z, mode) {\
   *(mode *) STACK_TOP = (z);\
   INCREMENT_STACK_POINTER (p, SIZE_ALIGNED (mode));\
@@ -302,42 +315,47 @@
   (*(z)) = *((mode *) STACK_TOP);\
   }
 
-#define PUSH_COMPLEX(p, re, im) {\
-  PUSH_PRIMAL (p, re, REAL);\
-  PUSH_PRIMAL (p, im, REAL);\
+#define PUSH_COMPLEX_VALUE(p, re, im) {\
+  PUSH_VALUE (p, re, A68G_REAL);\
+  PUSH_VALUE (p, im, A68G_REAL);\
   }
 
 #define POP_COMPLEX(p, re, im) {\
-  POP_OBJECT (p, im, A68_REAL);\
-  POP_OBJECT (p, re, A68_REAL);\
+  POP_OBJECT (p, im, A68G_REAL);\
+  POP_OBJECT (p, re, A68G_REAL);\
   }
 
 #define PUSH_BYTES(p, k) {\
-  A68_BYTES *_z_ = (A68_BYTES *) STACK_TOP;\
+  A68G_BYTES *_z_ = (A68G_BYTES *) STACK_TOP;\
   STATUS (_z_) = INIT_MASK;\
-  MOVE (VALUE (_z_), k, A68_BYTES_WIDTH);\
-  INCREMENT_STACK_POINTER((p), SIZE_ALIGNED (A68_BYTES));\
+  MOVE (VALUE (_z_), k, A68G_BYTES_WIDTH);\
+  INCREMENT_STACK_POINTER((p), SIZE_ALIGNED (A68G_BYTES));\
   }
 
 #define PUSH_LONG_BYTES(p, k) {\
-  A68_LONG_BYTES *_z_ = (A68_LONG_BYTES *) STACK_TOP;\
+  A68G_LONG_BYTES *_z_ = (A68G_LONG_BYTES *) STACK_TOP;\
   STATUS (_z_) = INIT_MASK;\
-  MOVE (VALUE (_z_), k, A68_LONG_BYTES_WIDTH);\
-  INCREMENT_STACK_POINTER((p), SIZE_ALIGNED (A68_LONG_BYTES));\
+  MOVE (VALUE (_z_), k, A68G_LONG_BYTES_WIDTH);\
+  INCREMENT_STACK_POINTER((p), SIZE_ALIGNED (A68G_LONG_BYTES));\
   }
 
-#define PUSH_REF(p, z) PUSH_OBJECT (p, z, A68_REF)
-#define PUSH_PROCEDURE(p, z) PUSH_OBJECT (p, z, A68_PROCEDURE)
-#define PUSH_FORMAT(p, z) PUSH_OBJECT (p, z, A68_FORMAT)
+#define PUSH_REF(p, z) PUSH_OBJECT (p, z, A68G_REF)
+#define PUSH_PROCEDURE(p, z) PUSH_OBJECT (p, z, A68G_PROCEDURE)
+#define PUSH_FORMAT(p, z) PUSH_OBJECT (p, z, A68G_FORMAT)
 
-#define POP_REF(p, z) POP_OBJECT (p, z, A68_REF)
-#define POP_PROCEDURE(p, z) POP_OBJECT (p, z, A68_PROCEDURE)
+#define PUSH_STRING(p, z) {\
+  char *_s_ = (z);\
+  PUSH_REF ((p), tmp_to_a68g_string ((p), _s_));\
+  }
+
+#define POP_REF(p, z) POP_OBJECT (p, z, A68G_REF)
+#define POP_PROCEDURE(p, z) POP_OBJECT (p, z, A68G_PROCEDURE)
 
 #define PUSH_UNION(p, z) {\
-  A68_UNION *_x_ = (A68_UNION *) STACK_TOP;\
+  A68G_UNION *_x_ = (A68G_UNION *) STACK_TOP;\
   STATUS (_x_) = INIT_MASK;\
   VALUE (_x_) = (z);\
-  INCREMENT_STACK_POINTER ((p), SIZE_ALIGNED (A68_UNION));\
+  INCREMENT_STACK_POINTER ((p), SIZE_ALIGNED (A68G_UNION));\
   }
 
 // Interpreter macros
@@ -355,27 +373,27 @@
 
 #define CHECK_INIT(p, c, q)\
   if (!(c)) {\
-    diagnostic (A68_RUNTIME_ERROR, (p), ERROR_EMPTY_VALUE_FROM, (q));\
-    exit_genie ((p), A68_RUNTIME_ERROR);\
+    diagnostic (A68G_RUNTIME_ERROR, (p), ERROR_EMPTY_VALUE_FROM, (q));\
+    exit_genie ((p), A68G_RUNTIME_ERROR);\
   }
 
 #define CHECK_DNS2(p, scope, limit, mode)\
   if (scope > limit) {\
     BUFFER txt;\
     ASSERT (a68g_bufprt (txt, SNPRINTF_SIZE, ERROR_SCOPE_DYNAMIC_1) >= 0);\
-    diagnostic (A68_RUNTIME_ERROR, p, txt, mode);\
-    exit_genie (p, A68_RUNTIME_ERROR);\
+    diagnostic (A68G_RUNTIME_ERROR, p, txt, mode);\
+    exit_genie (p, A68G_RUNTIME_ERROR);\
   }
 
 #define CHECK_DNS(p, m, w, limit)\
   if (NEED_DNS (GINFO (p))) {\
-    ADDR_T _lim = ((limit) < A68_GLOBALS ? A68_GLOBALS : (limit));\
+    ADDR_T _lim = ((limit) < A68G_GLOBALS ? A68G_GLOBALS : (limit));\
     if (IS ((m), REF_SYMBOL)) {\
-      CHECK_DNS2 (p, (REF_SCOPE ((A68_REF *) (w))), _lim, (m));\
+      CHECK_DNS2 (p, (REF_SCOPE ((A68G_REF *) (w))), _lim, (m));\
     } else if (IS ((m), PROC_SYMBOL)) {\
-      CHECK_DNS2 (p, ENVIRON ((A68_PROCEDURE *) (w)), _lim, (m));\
+      CHECK_DNS2 (p, ENVIRON ((A68G_PROCEDURE *) (w)), _lim, (m));\
     } else if (IS ((m), FORMAT_SYMBOL)) {\
-      CHECK_DNS2 (p, ENVIRON ((A68_FORMAT *) w), _lim, (m));\
+      CHECK_DNS2 (p, ENVIRON ((A68G_FORMAT *) w), _lim, (m));\
   }}
 
 // 
@@ -452,13 +470,13 @@ PROP_T genie_voiding (NODE_T *);
 PROP_T genie_widen_int_to_real (NODE_T *);
 PROP_T genie_widen (NODE_T *);
 
-A68_REF genie_clone (NODE_T *, MOID_T *, A68_REF *, A68_REF *);
-A68_REF genie_make_ref_row_of_row (NODE_T *, MOID_T *, MOID_T *, ADDR_T);
-A68_REF genie_make_ref_row_row (NODE_T *, MOID_T *, MOID_T *, ADDR_T);
-A68_REF genie_make_rowrow (NODE_T *, MOID_T *, int, ADDR_T);
+A68G_REF genie_clone (NODE_T *, MOID_T *, A68G_REF *, A68G_REF *);
+A68G_REF genie_make_ref_row_of_row (NODE_T *, MOID_T *, MOID_T *, ADDR_T);
+A68G_REF genie_make_ref_row_row (NODE_T *, MOID_T *, MOID_T *, ADDR_T);
+A68G_REF genie_make_rowrow (NODE_T *, MOID_T *, int, ADDR_T);
 
 void genie (void *);
-void genie_clone_stack (NODE_T *, MOID_T *, A68_REF *, A68_REF *);
+void genie_clone_stack (NODE_T *, MOID_T *, A68G_REF *, A68G_REF *);
 void genie_serial_units_no_label (NODE_T *, ADDR_T, NODE_T **);
 void genie_jump (NODE_T *);
 
